==> simple_shared_pref-2.0.2.tar.gz: lib/crypto_module.dart <==
import 'dart:convert';
import 'package:encrypt/encrypt.dart';
import 'package:simple_shared_pref/simple_shared_pref.dart';

/// The `CryptoModule` class provides a simple interface for encrypting and decrypting data using the AES encryption algorithm.
/// It also includes methods for initializing and managing encryption keys and initialization vectors (IV).
class CryptoModule {
  static final String _obfuscatedKey = 'cWYVJfZQ3JxjVVEEz3NJ';
  static final String _obfuscatedIV = 'S2dyXZrVGASgRK6nrzUV';

  /// Throws a custom exception when trying to store a value with the obfuscated key (_obfuscatedKey).
  void _checkKey(String key) {
    if (key == _obfuscatedKey) {
      throw CryptoException('Cannot store a value with the obfuscated key.');
    }
  }

  /// Throws a custom exception when trying to store a value with the obfuscated IV (_obfuscatedIV).
  void _checkIV(String key) {
    if (key == _obfuscatedIV) {
      throw CryptoException('Cannot store a value with the obfuscated IV.');
    }
  }

  /// Encrypts the provided [data] using the AES encryption algorithm and the generated encryption key.
  /// Returns the encrypted data as a base64-encoded string.
  String encryptData(String data) {
    try {
      final algorithm = AES(_requiredKey!);
      final enc = Encrypter(algorithm);
      final encrypted = enc.encrypt(data, iv: _iv);
      return encrypted.base64;
    } catch (e) {
      print('Encryption error: $e');
      return data;
    }
  }

  /// Decrypts the provided [encryptedData] using the AES encryption algorithm and the generated encryption key.
  /// Returns the decrypted data as a string.
  String decryptData(String encryptedData) {
    try {
      final algorithm = AES(_requiredKey!);
      final enc = Encrypter(algorithm);
      final decrypted = enc.decrypt64(encryptedData, iv: _iv);
      return decrypted;
    } catch (e) {
      print('Decryption error: $e');
      return encryptedData;
    }
  }

  /// Initializes the CryptoModule by generating and storing a new encryption key and initialization vector (IV) in SimpleSharedPref.
  /// It only runs once and is safe to be called on app startup.
  void init() {
    try {
      final key = Key.fromSecureRandom(32);
      final iv = IV.fromSecureRandom(16);
      if (!SimpleSharedPref().containsKey(_obfuscatedKey)) {
        SimpleSharedPref().setValue<String>(key: _obfuscatedKey, value: key.base64);
        SimpleSharedPref().setValue<String>(key: _obfuscatedIV, value: iv.base64);
      }
    } catch (e) {
      print('Initialization error: $e');
    }
  }

  void check(String key){
    _checkKey(key);
    _checkIV(key);
  }

  /// Retrieves the encryption key from SimpleSharedPref and converts it to a usable Key object.
  Key? get _requiredKey {
    try {
      return Key.fromBase64(
        base64.encode(utf8.encode(SimpleSharedPref().getValue<String>(key: _obfuscatedKey)!)),
      );
    } catch (e) {
      print('Key retrieval error: $e');
      return null;
    }
  }

  /// Retrieves the initialization vector (IV) from SimpleSharedPref and converts it to a usable IV object.
  IV? get _iv {
    try {
      return IV.fromBase64(
        base64.encode(utf8.encode(SimpleSharedPref().getValue<String>(key: _obfuscatedIV)!)),
      );
    } catch (e) {
      print('IV retrieval error: $e');
      return null;
    }
  }
}

/// Custom exception class for CryptoModule.
class CryptoException implements Exception {
  final String message;

  CryptoException(this.message);

  @override
  String toString() => 'CryptoException: $message';
}

==> simple_shared_pref-2.0.3.tar.gz: lib/crypto_module.dart <==
import 'dart:convert';
import 'package:encrypt/encrypt.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:simple_shared_pref/simple_shared_pref.dart';

/// The `CryptoModule` class provides a simple interface for encrypting and decrypting data using the AES encryption algorithm.
/// It also includes methods for initializing and managing encryption keys and initialization vectors (IV).
class CryptoModule {
  static final String _obfuscatedKey = 'cWYVJfZQ3JxjVVEEz3NJ';
  static final String _obfuscatedIV = 'S2dyXZrVGASgRK6nrzUV';

  /// Throws a custom exception when trying to store a value with the obfuscated key (_obfuscatedKey).
  void _checkKey(String key) {
    if (key == _obfuscatedKey) {
      throw CryptoException('Cannot store a value with the obfuscated key.');
    }
  }

  /// Throws a custom exception when trying to store a value with the obfuscated IV (_obfuscatedIV).
  void _checkIV(String key) {
    if (key == _obfuscatedIV) {
      throw CryptoException('Cannot store a value with the obfuscated IV.');
    }
  }

  /// Encrypts the provided [data] using the AES encryption algorithm and the generated encryption key.
  /// Returns the encrypted data as a base64-encoded string.
  String encryptData(String data) {
    try {
      final algorithm = AES(_requiredKey!);
      final enc = Encrypter(algorithm);
      final encrypted = enc.encrypt(data, iv: _iv);
      return encrypted.base64;
    } catch (e) {
      print('Encryption error: $e');
      return data;
    }
  }

  /// Decrypts the provided [encryptedData] using the AES encryption algorithm and the generated encryption key.
  /// Returns the decrypted data as a string.
  String decryptData(String encryptedData) {
    try {
      final algorithm = AES(_requiredKey!);
      final enc = Encrypter(algorithm);
      final decrypted = enc.decrypt64(encryptedData, iv: _iv);
      return decrypted;
    } catch (e) {
      print('Decryption error: $e');
      return encryptedData;
    }
  }

  /// Initializes the CryptoModule by generating and storing a new encryption key and initialization vector (IV) in SimpleSharedPref.
  /// It only runs once and is safe to be called on app startup.
  void init() {
    try {
      final key = Key.fromSecureRandom(32);
      final iv = IV.fromSecureRandom(16);
      if (!SimpleSharedPref().containsKey(_obfuscatedKey)) {
        SimpleSharedPref().preferences?.setString(_obfuscatedKey, key.base64);
        SimpleSharedPref().preferences?.setString(_obfuscatedIV, iv.base64);
      }
    } catch (e) {
      print('Initialization error: $e');
    }
  }

  void check(String key) {
    _checkKey(key);
    _checkIV(key);
  }

  /// Retrieves the encryption key from SimpleSharedPref and converts it to a usable Key object.
  Key? get _requiredKey {
    try {
      return Key.fromBase64(
        base64.encode(utf8
            .encode(SimpleSharedPref().getValue<String>(key: _obfuscatedKey)!)),
      );
    } catch (e) {
      print('Key retrieval error: $e');
      return null;
    }
  }

  /// Retrieves the initialization vector (IV) from SimpleSharedPref and converts it to a usable IV object.
  IV? get _iv {
    try {
      return IV.fromBase64(
        base64.encode(utf8
            .encode(SimpleSharedPref().getValue<String>(key: _obfuscatedIV)!)),
      );
    } catch (e) {
      print('IV retrieval error: $e');
      return null;
    }
  }
}

/// Custom exception class for CryptoModule.
class CryptoException implements Exception {
  final String message;

  CryptoException(this.message);

  @override
  String toString() => 'CryptoException: $message';
}
